#!/bin/bash

###########################################################
# This script allows to automatically generate all the
# localized HTML files for the Online version of the Ubuntu
# Start Page starting from the translated po files.
#
# USAGE:
# - simply put all the .po files in the locales/ directory
#   and run the script.
#   All the necessary files will be generated in the
#   online/ directory
#
# RESULTS:
# online/*  -> what should be copied into the VERSION/
#              directory on http://start.ubuntu.com/
#
###########################################################

# Check minimum requirements
PO2HTML=`which po2html`
TIDY=`which tidy`

if [ -z "${PO2HTML}" ]
then
	echo "ERROR - The program 'po2html' is not installed."
	echo "It can be found in the 'translate-toolkit' package."
	exit 1
fi

if [ -z "${TIDY}" ]
then
	echo "ERROR - The program 'po2html' is not installed."
	echo "It can be found in the 'tidy' package."
	exit 2
fi

# Search all PO files in the 'locales' directory
cd locales/9.04/po
POLIST=`ls *.po`
cd ../../..

# Create all the localized HTML pages for online Ubuntu Start Page
for POFILE in ${POLIST}
do
	LOCALE=`echo ${POFILE} | sed s/'\..*$'/''/`
	ONLINEFILE="output/index.html.${LOCALE}"

	po2html -i locales/9.04/po/${POFILE} -o ${ONLINEFILE} -t templates/9.04/index_template.html
	tidy -i --quiet yes --char-encoding utf8 -m ${ONLINEFILE}
	sed -i s/"{lang}"/"${LOCALE}"/ ${ONLINEFILE}
done

exit 0
