#!/bin/sh

# USAGE
# copy the archive downloaded from Rosetta in tha same dir
# copy the HTML file in the same dir
# check the variables


#name of the template html files to be translated
template_page="templates/9.04/index_template.html";

#name of the result page , lang will be appended here
output_page="../www/9.04/index.html"

#where is the launchpad export archive
locale_dir="locales/9.04";

#domain name for the rosetta exported file
domain="startpage"

#list of language code using RTL scripts
rtl_langs="he ps ar ur";

#text as it appers in pot file
title_en="Ubuntu Start Page";
search_en="Search";
help_en="Ubuntu Help"
shop_en="Ubuntu shop"
participate_en="Participate"

export LANG=C

####
# extract launchpad tar file
back_dir=`pwd`
cd "$locale_dir"
mkdir -p po
tar -xzf launchpad-export.tar.gz
mv $domain/locales/*.po po
mv $domain/*.po po
cp $domain/*.pot .
rm -rf $domain

#rename po files
for po in po/$domain-*.po ; do
po_good=${po#po/$domain-}
mv $po po/$po_good
done
cd "$back_dir"

# end of extraction
##########


####
# start the translation
for po in ${locale_dir}/po/*.po
do

# get lang name
lang=${po#$locale_dir/po/}
lang=${lang%.po}

#ingore if lang file has untranlsated of fuzzy text
msgfmt -o  /dev/null --statistics $po 2>&1 | grep untranslated > /dev/null
if [ $? = 0 ] ; then
echo "Ignoring $lang as it is not complete"
continue
fi

#init page
cp $template_page ${output_page}.$lang

#add html rtl attribute
for rtl_lang in $rtl_langs ; do
    if [ $rtl_lang = $lang ] ; then
        sed -i -e "s/\( lang=\"{lang}\"\)>/\1 dir=\"RTL\">/" ${output_page}.$lang
    fi
done

#add html lang attribute        
sed -i -e "s/{lang}/$lang/" ${output_page}.$lang

#translate page title
title_po=`msggrep --no-wrap -K -e "$title_en" $po | grep msgstr | grep -v "msgstr \"\"" | sed -e 's/msgstr "\(.*\)"/\1/'`
sed -i -e "s/<title>$title_en<\/title>/<title>$title_po<\/title>/" ${output_page}.$lang

#translate search text
search_po=`msggrep --no-wrap -K -e "$search_en" $po | grep msgstr | grep -v "msgstr \"\"" | sed -e 's/msgstr "\(.*\)"/\1/'`
sed -i -e "s/value=\"$search_en\"/value=\"$search_po\"/" ${output_page}.$lang


#translate help text
help_po=`msggrep --no-wrap -K -e "$help_en" $po | grep msgstr | grep -v "msgstr \"\"" | sed -e 's/msgstr "\(.*\)"/\1/'`
sed -i -e "s/$help_en/$help_po/" ${output_page}.$lang

#translate participate text
participate_po=`msggrep --no-wrap -K -e "$participate_en" $po | grep msgstr | grep -v "msgstr \"\"" | sed -e 's/msgstr "\(.*\)"/\1/'`
sed -i -e "s/$participate_en<\/a>/$participate_po<\/a>/" ${output_page}.$lang


#translate shop text
shop_po=`msggrep --no-wrap -K -e "$shop_en" $po | grep msgstr | grep -v "msgstr \"\"" | sed -e 's/msgstr "\(.*\)"/\1/'`
sed -i -e "s/$shop_en<\/a>/$shop_po<\/a>/" ${output_page}.$lang

done
